<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://www.spip.net/gl',
'0_langue' => 'Galego [gl]',
'0_liste' => 'spip-gl@rezo.net',
'0_mainteneur' => 'webmaster@avogacia.org',

// A
'access_interface_graphique' => 'Voltar &aacute; interface gr&aacute;fica completa',
'access_mode_texte' => 'Mostrar a interface de textos simplificada',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Modificar este artigo',
'admin_modifier_auteur' => 'Modificar este autor',
'admin_modifier_breve' => 'Modificar esta breve',
'admin_modifier_mot' => 'Modificar esta palabra-clave',
'admin_modifier_rubrique' => 'Modificar este tema',
'admin_recalculer' => 'Recargar a p&aacute;xina',
'afficher_trad' => 'mostrar as traduci&oacute;ns',
'alerte_maj_impossible' => '<b>Aviso&nbsp;!</b> A actualizaci&oacute;n da base SQL sobre a versi&oacute;n @version@ &eacute; imposible, poder&iacute;a ser por causa dun problema de permisos de modificaci&oacute;n da base de datos. Contacte co seu aloxador.',
'alerte_modif_info_concourante' => 'AVISO : esta informaci&oacute;n foi modificada por outros. O valor actual &eacute;&nbsp;:',
'analyse_xml' => 'An&aacute;lise XML',
'annuler' => 'Anular',
'antispam_champ_vide' => 'Deixe este campo baleiro, por favor&nbsp;:',
'articles_recents' => 'Artigos m&aacute;is recentes',
'avis_archive_incorrect' => 'o ficheiro arquivado non &eacute; un ficheiro SPIP',
'avis_archive_invalide' => 'o ficheiro arquivado non &eacute; v&aacute;lido',
'avis_attention' => 'ATENCI&Oacute;N!',
'avis_champ_incorrect_type_objet' => 'Nome de campo incorrecto @name@ para o obxecto de tipo @type@',
'avis_colonne_inexistante' => 'A columna @col@ non existe',
'avis_echec_syndication_01' => 'A afiliaci&oacute;n fallou: o ficheiro de &laquo;backend&raquo; indicado &eacute; indescifrable ou non trae ning&uacute;n artigo.',
'avis_echec_syndication_02' => 'A afiliaci&oacute;n fallou: foi imposible acceder ao ficheiro &laquo;backend&raquo; deste web.',
'avis_erreur' => 'Erro: ver abaixo',
'avis_erreur_connexion' => 'Erro de conexi&oacute;n',
'avis_erreur_cookie' => 'problema de cookie',
'avis_erreur_fonction_contexte' => 'Erro de programaci&oacute;n. Esta funci&oacute;n non debe ser chamada neste contexto.',
'avis_erreur_mysql' => 'Erro SQL',
'avis_erreur_sauvegarde' => 'Erro gardando (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Problema co acceso ao espazo privado',

// B
'barre_a_accent_grave' => 'Inserir un A con acento grave mai&uacute;sculo',
'barre_aide' => 'Utilice os recursos tipogr&aacute;ficos para enriquecer a s&uacute;a publicaci&oacute;n',
'barre_e_accent_aigu' => 'Inserir un E con acento agudo mai&uacute;sculo',
'barre_eo' => 'Inserir un E dentro do O',
'barre_eo_maj' => 'Inserir un E dentro do O mai&uacute;sculo',
'barre_euro' => 'Inserir o s&iacute;mbolo &euro;',
'barre_gras' => 'Po&ntilde;er en {{gras}}',
'barre_guillemets' => 'Encerrar entre &laquo; &aacute;ngulos &raquo;',
'barre_guillemets_simples' => 'Encerrar entre “comas dobres”',
'barre_intertitre' => 'Transformar en {{{intert&iacute;tulo}}}',
'barre_italic' => 'Po&ntilde;er en {cursiva}',
'barre_lien' => 'Transformar en [ligaz&oacute;n de hipertexto->http://...]',
'barre_lien_input' => 'Indicar o enderezo de seu web (pode indicar un enderezo de web coa forma http://www.monsite/com ou simplemente indicar o n&uacute;mero dun artigo deste web.',
'barre_note' => 'Transformar en [[Nota a rodap&eacute;]]',
'barre_paragraphe' => 'Crear un par&aacute;grafo',
'barre_quote' => '<quote>Citar unha mensaxe</quote>',
'bouton_ajouter_document' => 'Engadir un documento',
'bouton_ajouter_image' => 'Engadir unha imaxe',
'bouton_ajouter_image_document' => 'Engadir umha imaxe ou&nbsp;un&nbsp;documento',
'bouton_changer' => 'Trocar',
'bouton_chercher' => 'Buscar',
'bouton_choisir' => 'Elexir',
'bouton_download' => 'Descargar',
'bouton_enregistrer' => 'Rexistrar',
'bouton_radio_desactiver_messagerie_interne' => 'Desactivar a mensaxer&iacute;a interna',
'bouton_radio_envoi_annonces' => 'Enviar os anuncios editoriais',
'bouton_radio_non_envoi_annonces' => 'Non enviar novas',
'bouton_radio_non_envoi_liste_nouveautes' => 'Non enviar a lista de novidades',
'bouton_recharger_page' => 'recargar a p&aacute;xina',
'bouton_telecharger' => 'Cargar',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'mediod&iacute;a',
'cal_jour_entier' => 'd&iacute;a enteiro',
'cal_matin' => 'ma&ntilde;&aacute;',
'cal_par_jour' => 'calendario por d&iacute;a',
'cal_par_mois' => 'calendario por mes',
'cal_par_semaine' => 'calendario por semana',
'choix_couleur_interface' => 'cor',
'choix_interface' => 'escolla de interface',
'colonne' => 'Columna',
'confirm_changer_statut' => 'Coidado, pediu cambiar o estado deste elemento. Quere proceder?',
'correcte' => 'correcto',

// D
'date_aujourdhui' => 'hoxe',
'date_avant_jc' => 'a. de J.C.',
'date_dans' => 'en @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'ma&ntilde;&amp;aacute;',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ &aacute;s @heure@',
'date_fmt_jour_mois' => '@jour@ de @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ do @annee@',
'date_fmt_mois_annee' => '@nommois@ do @annee@',
'date_fmt_nomjour_date' => 'o @nomjour@ @date@',
'date_heures' => 'horas',
'date_hier' => 'onte',
'date_il_y_a' => 'fai @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'domingo',
'date_jour_1_abbr' => 'dom.',
'date_jour_1_initiale' => 'd.',
'date_jour_2' => 'luns',
'date_jour_2_abbr' => 'lun.',
'date_jour_2_initiale' => 'l.',
'date_jour_3' => 'martes',
'date_jour_3_abbr' => 'mar.',
'date_jour_3_initiale' => 'm.',
'date_jour_4' => 'm&eacute;rcores',
'date_jour_4_abbr' => 'mer.',
'date_jour_4_initiale' => 'm.',
'date_jour_5' => 'xoves',
'date_jour_5_abbr' => 'xov.',
'date_jour_5_initiale' => 'x.',
'date_jour_6' => 'venres',
'date_jour_6_abbr' => 'ven.',
'date_jour_6_initiale' => 'v.',
'date_jour_7' => 's&aacute;bado',
'date_jour_7_abbr' => 's&aacute;b.',
'date_jour_7_initiale' => 's.',
'date_jours' => 'd&iacute;as',
'date_minutes' => 'minutos',
'date_mois' => 'meses',
'date_mois_1' => 'xaneiro',
'date_mois_10' => 'outubro',
'date_mois_11' => 'novembro',
'date_mois_12' => 'decembro',
'date_mois_2' => 'febreiro',
'date_mois_3' => 'marzo',
'date_mois_4' => 'abril',
'date_mois_5' => 'maio',
'date_mois_6' => 'xu&ntilde;o',
'date_mois_7' => 'xullo',
'date_mois_8' => 'agosto',
'date_mois_9' => 'setembro',
'date_saison_1' => 'inverno',
'date_saison_2' => 'primavera',
'date_saison_3' => 'ver&aacute;n',
'date_saison_4' => 'outono',
'date_secondes' => 'segundos',
'date_semaines' => 'semanas',
'date_un_mois' => 'mes',
'date_une_heure' => 'hora',
'date_une_minute' => 'minuto',
'date_une_seconde' => 'segundo',
'date_une_semaine' => 'semana',
'dirs_commencer' => ' para comezar realmente a instalaci&oacute;n',
'dirs_preliminaire' => 'Preliminar: <b>Regular os permisos de acceso</b>',
'dirs_probleme_droits' => 'Problema de permisos de acceso',
'dirs_repertoires_absents' => '<p><b>Os directorios seguintes non foron atopados&nbsp;:</b></p><ul>@bad_dirs@.</ul>
  <p>&Eacute; probable que iso se deba a un problema de uso de mai&uacute;sculas ou min&uacute;sculas.
  Verifique que as min&uacute;sculas e mai&uacute;sculas destes cartafoles concorden ben co que se amosa
 aqu&iacute; abaixo; se non &eacute; ese o caso, renomee os cartafoles co seu programa de FTP de xeito que se corrixa o erro.</p>
  <p>Logo de facer este cambio, poder&aacute; ',
'dirs_repertoires_suivants' => '<p><b>Os cartafoles seguintes impiden o acceso con dereitos para escritura&nbsp;:</b></p><ul>@bad_dirs@.</ul>
  <p>Para arranxalo, empregue o seu cliente de FTP e cambie os permisos de acceso de cada un
  deles. O procedemento est&aacute; explicado polo mi&uacute;do na gu&iacute;a de instalaci&oacute;n.</p>
  <p>Unha vez feito isto, poder&aacute; ',
'double_occurrence' => 'Dobre ocorrencia de @balise@',

// E
'en_cours' => 'en curso',
'entree_dimensions' => 'Dimensi&oacute;ns:',
'entree_titre_document' => 'T&iacute;tulo do documento:',
'entree_titre_image' => 'T&iacute;tulo da imaxe:',
'envoi_via_le_site' => 'Env&iacute;o v&iacute;a o sitio web',
'erreur' => 'Erro',
'erreur_balise_non_fermee' => 'a &uacute;ltima baliza non foi pechada :',
'erreur_texte' => 'erro(s)',
'etape' => 'Etapa',

// F
'fichier_introuvable' => 'O ficheiro @fichier@ non foi atopado',
'form_auteur_confirmation' => 'Confirme o seu enderezo de correo',
'form_auteur_email_modifie' => 'Modificouse o seu enderezo de correo.',
'form_auteur_envoi_mail_confirmation' => 'Un correo electr&oacute;nico de confirmaci&oacute;n acaba de ser enviado a @email@. Deber&iacute;a visitar ese enderezo web mencionado no correo para validar o seu enderezo de correo.',
'form_auteur_mail_confirmation' => 'Ola,

Vostede solicitou cambiar o seu enderezo de correo.
Para confirmar o seu novo enderezo, c&oacute;mpre que se conecta co
enderezo seguinte (caso contrario, a s&uacute;a solicitude
sera ignorada) :

    @url@
',
'form_deja_inscrit' => 'Xa est&aacute; inscrito.',
'form_email_non_valide' => 'O seu enderezo de correo-e. non &eacute; v&aacute;lido.',
'form_forum_access_refuse' => 'Non tes acceso a este web.',
'form_forum_bonjour' => 'Ola, @nom@,',
'form_forum_email_deja_enregistre' => 'Este enderezo de correo xa est&aacute; rexistrado, daquela pode empregar a s&uacute;a chave de sempre.',
'form_forum_identifiant_mail' => 'Enviouselle a vostede o seu novo identificador por correo electr&oacute;nico.',
'form_forum_identifiants' => 'Identificadores persoais',
'form_forum_indiquer_nom_email' => 'Indique aqu&iacute; o seu nome e o seu enderezo de correo. Axi&ntilde;a recibir&aacute; o seu identificador persoal por correo electr&oacute;nico.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(esta &eacute; unha mensaxe autom&aacute;tica)',
'form_forum_pass' => 'chave:',
'form_forum_probleme_mail' => 'Problema co correo: non se lle puido enviar o identificador.',
'form_forum_voici1' => 'Velaqu&iacute; os seus datos identificadores para participar na vida
do web "@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Estes son os datos que precisa para propor artigos en "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Indique o seu enderezo de correo-e.',
'form_indiquer_nom' => 'Indica o teu nome.',
'form_indiquer_nom_site' => 'Indique o nome do seu web.',
'form_pet_adresse_site' => 'Enderezo do seu web',
'form_pet_aucune_signature' => 'Non hai nengunha sinatura que corresponda a este c&oacute;digo...',
'form_pet_confirmation' => 'Por favor, confirma a t&uacute;a sinatura:',
'form_pet_deja_enregistre' => 'Este web xa foi rexistrado',
'form_pet_deja_signe' => 'Xa asinou este texto.',
'form_pet_envoi_mail_confirmation' => 'Envi&oacute;uselle un correo electr&oacute;nico de confirmaci&oacute;n. Ter&aacute; que visitar o enderezo web mencionado nel para validar a s&uacute;a sinatura.',
'form_pet_mail_confirmation' => 'Bos d&iacute;as,

Pediu asinar a solicitude:
@titre@.

Proporcionou os seguintes datos:
     Nome: @nom_email@
     Web: @nom_site@ - @url_site@
     @message@

IMPORTANTE...
Para validar a s&uacute;a sinatura, s&oacute; ten que conectar co
enderezo de m&aacute;is abaixo (en caso contrario, a s&uacute;a solicitude
ser&aacute; rexeitada):

     @url@


Grazas pola s&uacute;a participaci&oacute;n
',
'form_pet_message_commentaire' => 'Algunha mensaxe, un comentario?',
'form_pet_nom_site2' => 'Nome do seu Web',
'form_pet_probleme_liens' => 'Retome a s&uacute;a mensaxe logo de suprimir as ligaz&oacute;ns de hipertexto.',
'form_pet_probleme_technique' => 'Problema t&eacute;cnico, as sinaturas foron suspendidas temporalmente.',
'form_pet_signature_pasprise' => 'A t&uacute;a sinatura non foi tida en conta.',
'form_pet_signature_validee' => 'A s&uacute;a sinatura foi validada. Deus llo pague!',
'form_pet_site_deja_enregistre' => 'Este web xa foi rexistrado',
'form_pet_url_invalide' => 'O URL que indicou non &eacute; v&aacute;lido.',
'form_pet_votre_email' => 'O seu enderezo de correo-e.',
'form_pet_votre_nom' => 'O teu nome ou alcume',
'form_pet_votre_site' => 'Se tes unha p&aacute;xina web, p&oacute;delo indicar aqu&iacute; embaixo',
'form_prop_confirmer_envoi' => 'Confirmar o env&iacute;o',
'form_prop_description' => 'Descrici&oacute;n/comentario',
'form_prop_enregistre' => 'A s&uacute;a proposta foi rexistrada, estar&aacute; en li&ntilde;a en canto sexa
  validada polo equipo de xesti&oacute;n deste web.',
'form_prop_envoyer' => 'Enviar unha mensaxe',
'form_prop_indiquer_email' => 'Indique un enderezo de correo-e. correcto',
'form_prop_indiquer_nom_site' => 'Indique o nome do web.',
'form_prop_indiquer_sujet' => 'Escrebe o asunto da mensaxe',
'form_prop_message_envoye' => 'Mensaxe enviada',
'form_prop_nom_site' => 'Nome do web',
'form_prop_non_enregistre' => 'A s&uacute;a proposta non foi rexistrada.',
'form_prop_sujet' => 'Asunto',
'form_prop_url_site' => 'Enderezo (URL) do web',
'forum_acces_refuse' => 'Non tes acceso a estes foros.',
'forum_attention_dix_caracteres' => '<b>Atenci&oacute;n!</b> a s&uacute;a mensaxe debe conter m&aacute;is de dez caracteres.',
'forum_attention_trois_caracteres' => '<b>Atenci&oacute;n!</b> o seu t&iacute;tulo debe ter m&aacute;is de tres caracteres.',
'forum_attention_trop_caracteres' => '<b>Atencion&nbsp;!</b> a mensaxe &eacute; demasiado longa (@compte@ caracteres)&nbsp;: para poder ser rexistrada, non debe sobrepasar  @max@ caracteres.',
'forum_avez_selectionne' => 'Seleccionou&nbsp;:',
'forum_cliquer_retour' => 'Preme <a href=\'@retour_forum@\'>aqu&iacute;</a> para seguir.',
'forum_forum' => 'foro',
'forum_info_modere' => 'Este foro &eacute; moderado a priori&nbsp;: a s&uacute;a contribuci&oacute;n non aparecer&aacute; namentres non sexa aprobada por un administrador do web.',
'forum_lien_hyper' => '<b>Ligaz&oacute;n de hipertexto</b> (opcional)',
'forum_message_definitif' => 'Mensaxe definitiva: enviala ao web',
'forum_message_trop_long' => 'A mensaxe &eacute; longa de m&aacute;is. O tama&ntilde;o m&aacute;ximo permitido &eacute; de 20000 caract&eacute;res.',
'forum_ne_repondez_pas' => 'Resposta este correo no foro do enderezo seguinte:',
'forum_non_inscrit' => 'A&iacute;nda non se rexistrou, ou o enderezo ou a chave son incorrectos.',
'forum_page_url' => '(Se a s&uacute;a mensaxe se refire a un artigo publicado en Internet, ou a unha p&aacute;xina que cont&eacute;n m&aacute;is informaci&oacute;ns, indique a continuaci&oacute;n o t&iacute;tulo da p&aacute;xina e o seu enderezo URL)',
'forum_par_auteur' => 'por @auteur@',
'forum_poste_par' => 'Mensaxe de @parauteur@ relacionada co artigo &laquo; @titre@ &raquo;.',
'forum_probleme_database' => 'Problema da base de datos, a s&uacute;a mensaxe non foi rexistrada.',
'forum_qui_etes_vous' => '<b>Quen &eacute; vostede?</b> (opcional)',
'forum_texte' => 'Texto da s&uacute;a mensaxe:',
'forum_titre' => 'T&iacute;tulo:',
'forum_titre_erreur' => 'Erro...',
'forum_url' => 'URL:',
'forum_valider' => 'Validar a elecci&oacute;n',
'forum_voir_avant' => 'Ver a mensaxe antes de enviala',
'forum_votre_email' => 'O teu enderezo de correo-e.:',
'forum_votre_nom' => 'O teu nome (ou alcume):',
'forum_vous_enregistrer' => 'Para participar neste foro, ten que se rexistrar
  con anterioridade. Escriba aqu&iacute; embaixo o identificador persoal
  que recibiu. Se a&iacute;nda non se rexistrou, d&eacute;beo facer',
'forum_vous_inscrire' => 'inscribirse.',

// I
'ical_texte_rss_articles' => 'O ficheiro &laquo;backend&raquo; dos artigos deste web enc&oacute;ntrase no enderezo:',
'ical_texte_rss_articles2' => 'Pode tam&eacute;n obter os ficheiros &laquo;backend&raquo; para os artigos de cada secci&oacute;n do web:',
'ical_texte_rss_breves' => 'Est&aacute; dispo&ntilde;ible un ficheiro que cont&eacute;n as breves do web. Especificando un n&uacute;mero de secci&oacute;n obter&aacute; unicamente as breves de tal secci&oacute;n.',
'icone_a_suivre' => 'Panel de control',
'icone_admin_site' => 'Xesti&oacute;n do web',
'icone_agenda' => 'Axenda',
'icone_aide_ligne' => 'Axuda en li&ntilde;a',
'icone_articles' => 'Artigos',
'icone_auteurs' => 'Equipo de redacci&oacute;n',
'icone_breves' => 'Breves',
'icone_brouteur' => 'Navegaci&oacute;n r&aacute;pida',
'icone_configuration_site' => 'Configuraci&oacute;n',
'icone_configurer_site' => 'Configurar o teu web',
'icone_creer_nouvel_auteur' => 'Crear un novo autor/a',
'icone_creer_rubrique' => 'Crear unha secci&oacute;n',
'icone_creer_sous_rubrique' => 'Crear unha subsecci&oacute;n',
'icone_deconnecter' => 'Desconectarse',
'icone_discussions' => 'Discusi&oacute;ns',
'icone_doc_rubrique' => 'Documento dos temas',
'icone_ecrire_article' => 'Escribir un novo artigo',
'icone_edition_site' => 'Edici&oacute;n',
'icone_forum_administrateur' => 'Foro de xesti&oacute;n',
'icone_forum_suivi' => 'Seguimento dos foros',
'icone_gestion_langues' => 'Xesti&oacute;n das linguas',
'icone_informations_personnelles' => 'Informaci&oacute;n persoal',
'icone_interface_complet' => 'Interface completa',
'icone_interface_simple' => 'Interface sinxela',
'icone_maintenance_site' => 'Mantemento do web',
'icone_messagerie_personnelle' => 'Mensaxer&iacute;a persoal',
'icone_mots_cles' => 'Palabras-clave',
'icone_nouvelle_breve' => 'Escribir unha nova breve',
'icone_repartition_actuelle' => 'Mostrar a distribuci&oacute;n actual',
'icone_repartition_debut' => 'Mostrar distribuci&oacute;n dende o principio',
'icone_repartition_visites' => 'Distribuci&oacute;n das visitas',
'icone_rubriques' => 'Temas',
'icone_sauver_site' => 'Copia de seguridade do web',
'icone_site_entier' => 'Todo o web',
'icone_sites_references' => 'Webs referidos',
'icone_statistiques' => 'Estat&iacute;sticas do web',
'icone_statistiques_visites' => 'Estat&iacute;sticas',
'icone_suivi_activite' => 'Seguir a vida do web',
'icone_suivi_actualite' => 'Evoluci&oacute;n do&nbsp;web',
'icone_suivi_forums' => 'Seguir/xestionar os foros',
'icone_suivi_pettions' => 'Seguir/xestionar as solicitudes',
'icone_suivi_revisions' => 'Modificaci&oacute;ns dos artigos',
'icone_supprimer_document' => 'Borrar este documento',
'icone_supprimer_image' => 'Borrar esta imaxe',
'icone_supprimer_message' => 'Borrar esta mensaxe',
'icone_tous_articles' => 'Os teus artigos',
'icone_tous_auteur' => 'Todo o equipo de redacci&oacute;n',
'icone_valider_message' => 'Validar a mensaxe',
'icone_visiter_site' => 'Ver o web',
'icone_voir_en_ligne' => 'Ver en li&ntilde;a',
'image_tourner_180' => 'Rotaci&oacute;n 180&deg;',
'image_tourner_droite' => 'Rotaci&oacute;n 90&deg; &aacute; dereita',
'image_tourner_gauche' => 'Rotaci&oacute;n 90&deg; &aacute; esquerda',
'img_indisponible' => 'imaxe non dispo&ntilde;&iacute;bel',
'impossible' => 'impos&iacute;bel',
'info_a_suivre' => 'PANEL DE CONTROL &raquo;',
'info_a_valider' => '[a validar]',
'info_acces_interdit' => 'Acceso prohibido',
'info_acces_refuse' => 'Acceso rexeitado',
'info_action' => 'Acci&oacute;n: @action@',
'info_administrer_rubriques' => 'Podes administrar este tema e os seus apartados',
'info_adresse_non_indiquee' => 'Non indicou un enderezo de proba!',
'info_aide' => 'AXUDA:',
'info_ajouter_mot' => 'Engadir esta palabra',
'info_annonce' => 'ANUNCIO',
'info_annonces_generales' => 'Anuncios xerais&nbsp;:',
'info_article_propose' => 'Artigo proposto',
'info_article_publie' => 'Artigo publicado',
'info_article_redaction' => 'Artigo en proceso de redacci&oacute;n',
'info_article_refuse' => 'Artigo rexeitado',
'info_article_supprime' => 'Artigo eliminado',
'info_articles' => 'Artigos',
'info_articles_a_valider' => 'Os artigos por validar',
'info_articles_nb' => '@nb@ artigos',
'info_articles_proposes' => 'Artigos propostos',
'info_articles_un' => '1 artigo',
'info_auteurs_nombre' => 'autor(as/es):',
'info_authentification_ftp' => 'Autentificaci&oacute;n (por FTP).',
'info_bloquer_lien' => 'Bloquear esta ligaz&oacute;n',
'info_breves_02' => 'Breves',
'info_breves_2' => 'breves',
'info_breves_nb' => '@nb@ breves',
'info_breves_un' => '1 breve',
'info_breves_valider' => 'Breves por validar',
'info_connexion_refusee' => 'Conexi&oacute;n rexeitada',
'info_contact_developpeur' => 'Tes que contactar cun desenrolador.',
'info_contenance' => 'Este web cont&eacute;n:',
'info_contribution' => 'contribuci&oacute;ns no foro',
'info_copyright' => '@spip@ &eacute; un programa libre distribu&iacute;do @lien_gpl@.',
'info_copyright_doc' => 'Para m&aacute;is informaci&oacute;n, vaia a <a href="@spipnet@">http://www.spip.net/gl</a>.',
'info_copyright_gpl' => 'con licenza GPL',
'info_cours_edition' => 'Os seus artigos en proceso de edici&oacute;n',
'info_creer_repertoire' => 'Debe crear un ficheiro ou cartafol chamado&nbsp;:',
'info_creer_repertoire_2' => 'dentro do subcartafol <b>@repertoire@</b>, e logo:',
'info_creer_vignette' => 'creaci&oacute;n autom&aacute;tica da vi&ntilde;eta',
'info_deplier' => 'Despregar',
'info_descriptif_nombre' => 'descrici&oacute;n(s):',
'info_description' => 'Descrici&oacute;n:',
'info_description_2' => 'Descrici&oacute;n:',
'info_dimension' => 'Dimensi&oacute;ns:',
'info_document' => 'Documento',
'info_document_indisponible' => 'Este documento non est&aacute; dispo&ntilde;ible',
'info_documents' => 'Documentos',
'info_documents_nb' => '@nb@ documentos',
'info_documents_un' => '1 documento',
'info_echange_message' => 'SPIP permite o intercambio de mensaxes e a constituci&oacute;n de foros de discusi&oacute;n
  privados entre os participantes do web. Pode activar ou
  desactivar esta funcionalidade.',
'info_ecire_message_prive' => 'Escribir unha mensaxe privada',
'info_email_invalide' => 'Enderezo de correo-e. incorrecto.',
'info_en_cours_validation' => 'Os seus artigos en proceso de redacci&oacute;n',
'info_en_ligne' => 'Agora en li&ntilde;a&nbsp;:',
'info_envoyer_message_prive' => 'enviar unha mensaxe privada a esta persoa',
'info_erreur_requete' => 'Erro na petici&oacute;n:',
'info_erreur_squelette2' => 'Ning&uacute;n esqueleto <b>@fichier@</b> est&aacute; dispo&ntilde;ible...',
'info_erreur_systeme' => 'Erro do sistema (errno @errsys@)',
'info_erreur_systeme2' => 'O disco duro pode ser que estea cheo, ou a base de datos danada. <br />
 <font color=\'red\'>Probe a <a href=\'@script@\'>reparar a base</a>,
 ou contacte co seu aloxador.</font>',
'info_fini' => 'Rematou!',
'info_format_image' => 'Formatos de imaxes que poden ser utilizados para crear as vi&ntilde;etas: @gd_formats@.',
'info_format_non_defini' => 'formato non definido',
'info_grand_ecran' => 'Pantalla grande',
'info_image_aide' => 'AXUDA',
'info_image_process_titre' => 'M&eacute;todo de produci&oacute;n das vi&ntilde;etas',
'info_impossible_lire_page' => '<b>Erro!</b> Foi imposible ler a p&amp;aacute;xina <tt><html>@test_proxy@</html></tt> a trav&amp;eacute;s do proxy <tt>',
'info_inclusion_directe' => 'Inclusi&oacute;n directa:',
'info_inclusion_vignette' => 'Inclusi&oacute;n da vi&ntilde;eta:',
'info_installation_systeme_publication' => 'Instalaci&oacute;n do sistema de publicaci&oacute;n...',
'info_installer_documents' => 'Pode instalar automaticamente todos os documentos contidos no cartafol ou directorio @upload@.',
'info_installer_ftp' => 'Como administrador, pode instalar (por FTP) os ficheiros no cartafol  /@upload@ para despois podelos seleccionar directamente aqu&iacute;.',
'info_installer_images' => 'Podes instalar imaxes nos formatos PNG, JPEG e GIF.',
'info_installer_images_dossier' => 'Instalar imaxes no cartafol @upload@ para poder seleccionalas aqu&iacute;.',
'info_installer_tous_documents' => 'Instalar todos os documentos',
'info_interface_complete' => 'Interface completa',
'info_interface_simple' => 'Interface sinxela',
'info_joindre_document_article' => 'Podes engadir a este artigo documentos do tipo',
'info_joindre_document_rubrique' => 'Podes engadir neste tema documentos do tipo',
'info_joindre_documents_article' => 'Podes engadir &oacute; teu artigo documentos do tipo:',
'info_l_article' => 'o artigo',
'info_la_breve' => 'a breve',
'info_la_rubrique' => 'o tema',
'info_langue_principale' => 'Idioma principal do web',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixels',
'info_les_auteurs_1' => 'por @les_auteurs@',
'info_logo_format_interdit' => 'S&oacute; est&aacute;n permitidos os logos nos seguintes formatos @formats@.',
'info_logo_max_poids' => 'Os logos deben obrigatoriamente ter menos de @maxi@ (este ficheiro ten @actuel@).',
'info_logo_max_taille' => 'Os logos deben obrigatoriamente ter menos de @maxi@ (este ficheiro ten @actuel@).',
'info_mail_fournisseur' => 'oteu@aloxador.com',
'info_message_2' => 'MENSAXE',
'info_message_supprime' => 'MENSAXE ELIMINADA',
'info_messages_nb' => '@nb@ mensaxes',
'info_messages_un' => '1 mensaxe',
'info_mise_en_ligne' => 'Data de posta en li&ntilde;a:',
'info_modification_parametres_securite' => 'modificaci&oacute;ns dos par&aacute;metros de seguridade',
'info_mois_courant' => 'Neste mes:',
'info_mot_cle_ajoute' => 'A seguinte palabra-clave foi engadida a',
'info_multi_herit' => 'Lingua predeterminada',
'info_multi_langues_soulignees' => 'As <u>linguas subli&ntilde;adas</u> benef&iacute;cianse dunha traduci&oacute;n de todos os textos da interface. Se vostede selecciona estas linguas, haber&aacute; numerosos elementos do web p&uacute;blico (datos, formularios)que ser&aacute;n automaticamente traducidos. Para as linguas non subli&ntilde;adas, estes elementos aparecer&aacute;n na lingua principal do web.',
'info_multilinguisme' => 'Multiling&uuml;ismo',
'info_nom_non_utilisateurs_connectes' => 'O seu nome non aparece na lista de persoas conectadas.',
'info_nom_utilisateurs_connectes' => 'O seu nome aparece na lista de persoas conectadas.',
'info_nombre_en_ligne' => 'Actualmente en li&ntilde;a:',
'info_non_resultat' => 'Non hai ning&uacute;n resultado con "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Non est&aacute; empregando a mensaxer&iacute;a interna deste web.',
'info_nouveau_message' => 'TES UNHA NOVA MENSAXE',
'info_nouveaux_messages' => 'TES @total_messages@ NOVAS MENSAXES',
'info_numero_abbreviation' => 'N&uacute;m.&nbsp;',
'info_obligatoire' => 'Esta informaci&oacute;n &eacute; obrigada',
'info_panne_site_syndique' => 'Web afiliado ca&iacute;do',
'info_pense_bete' => 'NOTA',
'info_petit_ecran' => 'Pantalla pequena',
'info_petition_close' => 'Solicitude pechada',
'info_pixels' => 'pixels',
'info_plusieurs_mots_trouves' => 'Foron atopadas varias palabras-clave para "@cherche_mot@":',
'info_popularite_5' => 'popularidade&nbsp;:',
'info_portfolio' => 'cartafol',
'info_portfolio_automatique' => 'Portafolio autom&aacute;tico:',
'info_premier_resultat' => '[@debut_limit@ primeiros resultados de @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ primeiros resultados de @total@]',
'info_probleme_grave' => 'problema de',
'info_propose_1' => '[@nom_site_spip@] Proposto: @titre@',
'info_propose_2' => 'Artigo proposto
---------------',
'info_propose_3' => 'O artigo "@titre@" foi proposto para a s&uacute;a publicaci&oacute;n.',
'info_propose_4' => 'Cons&uacute;lteo e achegue a s&uacute;a opini&oacute;n',
'info_propose_5' => 'no foro correspondente. Est&aacute; dispo&ntilde;ible no enderezo : ',
'info_publie_01' => 'O artigo "@titre@" foi validado por @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLICADO: @titre@',
'info_publie_2' => 'Artigo publicado
--------------',
'info_rechercher' => 'Buscar',
'info_rechercher_02' => 'Buscar:',
'info_remplacer_vignette' => 'Trocar a vi&ntilde;eta por defecto por un logo persoal:',
'info_retablir_lien' => 'reestablecer esta ligaz&oacute;n',
'info_retirer_mot' => 'Retirar esta palabra',
'info_retirer_mots' => 'Retirar todas as palabras',
'info_rubriques_nb' => '@nb@ secci&oacute;ns',
'info_rubriques_un' => '1 secci&oacute;ns',
'info_sans_titre_2' => 'sen t&iacute;tulo',
'info_selectionner_fichier' => 'Pode seleccionar un ficheiro do cartafol @upload@',
'info_selectionner_fichier_2' => 'Seleccionar un ficheiro:',
'info_signature_supprimee' => 'Sinatura suprimida',
'info_signature_supprimee_erreur' => 'Erro&nbsp;: este c&oacute;digo de supresi&oacute;n non corresponde a ningunha sinatura',
'info_site_attente' => 'Sitio web agardando pola validaci&oacute;n',
'info_site_reference' => 'Web referido en li&ntilde;a',
'info_site_refuse' => 'Web rexeitado',
'info_sites_nb' => '@nb@ webs',
'info_sites_referencer' => 'Referenciar un web',
'info_sites_un' => '1 web',
'info_supprimer_vignette' => 'suprimir a vi&ntilde;eta',
'info_symbole_bleu' => 'O s&amp;iacute;mbolo <b>azul</b> indica unha <b>nota</b>: ou sexa, unha mensaxe para o seu uso persoal.',
'info_symbole_jaune' => 'O s&iacute;mbolo <b>amarelo</b> indica un <b>anuncio para todo o equipo de redacci&oacute;n</b>&nbsp;: modificable polo equipo de xesti&oacute;n, e visible por toda a redacci&oacute;n.',
'info_symbole_vert' => 'O s&iacute;mbolo <b>verde</b> indica as <b>mensaxes intercambiadas con outros usuarios</b> do web.',
'info_syndication' => 'sindicaci&oacute;n&nbsp;:',
'info_syndication_articles' => 'artigo(s)',
'info_telecharger' => 'Cargar desde a s&uacute;a computadora:',
'info_telecharger_nouveau_logo' => 'Cargar un novo logo:',
'info_telecharger_ordinateur' => 'Cargar dende a s&uacute;a computadora:',
'info_tous_resultats_enregistres' => '[todos os resultados foron rexistrados]',
'info_tout_afficher' => 'Amosar todo',
'info_travaux_texte' => 'Este web non est&aacute; a&iacute;nda configurado. Volva m&aacute;is adiante...',
'info_travaux_titre' => 'Web en construci&oacute;n',
'info_trop_resultat' => 'Resultados de m&aacute;is para "@cherche_mot@" ; por favor, afine a s&uacute;a procura.',
'info_utilisation_messagerie_interne' => 'Est&aacute;s empregando a mensaxer&iacute;a interna deste web.',
'info_valider_lien' => 'validar esta ligaz&oacute;n',
'info_verifier_image' => ', verifique que as imaxes foron transferidas correctamente.',
'info_vignette_defaut' => 'Vi&ntilde;eta predeterminada',
'info_vignette_personnalisee' => 'Vi&ntilde;eta personalizada',
'info_visite' => 'visita:',
'info_visites' => 'visitas:',
'info_vos_rendez_vous' => 'As t&uacute;as citas pendentes',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'As t&uacute;as notas',
'item_breve_proposee' => 'Breve proposta',

// L
'lien_afficher_icones_seuls' => 'Amosar s&oacute; as iconas',
'lien_afficher_texte_icones' => 'Amosar as iconas e o texto',
'lien_afficher_texte_seul' => 'Amosar s&oacute; o texto',
'lien_liberer' => 'liberar',
'lien_liberer_tous' => 'liberar estes artigos',
'lien_nouvea_pense_bete' => 'NOVA NOTA',
'lien_nouveau_message' => 'NOVA MENSAXE',
'lien_nouvelle_annonce' => 'NOVO ANUNCIO',
'lien_petitions' => 'SOLICITUDE',
'lien_popularite' => 'popularidade&nbsp;: @popularite@%',
'lien_racine_site' => 'RA&Iacute;Z DO WEB',
'lien_reessayer' => 'reintentar',
'lien_repondre_message' => 'Responder a esta mensaxe',
'lien_supprimer' => 'Suprimir',
'lien_tout_afficher' => 'Amosar todo',
'lien_visite_site' => 'visitar este web',
'lien_visites' => '@visites@ visitas',
'lien_voir_auteur' => 'Ver est@ autor/a',
'ligne' => 'Li&amp;nacute;a',
'login' => 'Conexi&oacute;n',
'login_acces_prive' => 'acceso ao espazo privado',
'login_autre_identifiant' => 'conectarse con outro identificador',
'login_cookie_accepte' => 'Axuste o seu navegador para que as acepte (cando menos para este web).',
'login_cookie_oblige' => 'Para indentificarse dun xeito seguro neste webr, ten que aceptar as cookies.',
'login_deconnexion_ok' => 'Desconexi&oacute;n realizada.',
'login_erreur_pass' => 'Erro na chave.',
'login_espace_prive' => 'Espazo privado',
'login_identifiant_inconnu' => 'O identificador &laquo; @login@ &raquo; &eacute; desco&ntilde;ecido.',
'login_login' => 'Login:',
'login_login2' => 'Login (identificador de conexi&oacute;n ao web):',
'login_login_pass_incorrect' => '(Login ou chave incorrectos.)',
'login_motpasseoublie' => 'esqueceu a chave?',
'login_non_securise' => 'Atenci&oacute;n, este formulario non &eacute; seguro.
  Se non quere que a s&uacute;a chave poida ser interceptada
  na rede, active o Javascript no seu navegador e',
'login_nouvelle_tentative' => 'Nova tentativa',
'login_par_ici' => 'Vostede est&aacute; xa rexistrado... por aqu&iacute;...',
'login_pass2' => 'Chave&nbsp;:',
'login_preferez_refuser' => '<b>Se prefire non usar as cookies</b>, ten outro m&eacute;todo de conexi&oacute;n (menos seguro) &aacute; s&uacute;a disposici&oacute;n:',
'login_recharger' => 'recargar a p&aacute;xina',
'login_rester_identifie' => 'Permanecer identificado alg&uacute;ns d&iacute;as',
'login_retour_public' => 'Volver ao web p&uacute;blico',
'login_retour_site' => 'Volver ao web p&uacute;blico',
'login_retoursitepublic' => 'volver ao web p&uacute;blico',
'login_sans_cookiie' => 'Identificaci&oacute;n sen cookie',
'login_securise' => 'Inicio de sesi&oacute;n securizado',
'login_sinscrire' => 'Inscribirse',
'login_test_navigateur' => 'proba navegador/reconexi&oacute;n',
'login_verifiez_navigateur' => '(De todos os xeitos, comprobe que o seu navegador non memorizou a s&uacute;a chave...)',

// M
'masquer_colonne' => 'Ocultar esta columna',
'masquer_trad' => 'ocultar as traduci&oacute;ns',
'module_fichiers_langues' => 'Ficheiros de lingua',

// N
'navigateur_pas_redirige' => 'Se o seu navegador non &eacute; redirixido, prema aqu&iacute; para continuar.',
'numero' => 'N&uacute;mero',

// O
'occurence' => 'Ocorrencia',
'onglet_affacer_base' => 'Eliminar a base',
'onglet_auteur' => 'A persoa',
'onglet_contenu_site' => 'Contido do web',
'onglet_evolution_visite_mod' => 'Evoluci&oacute;n',
'onglet_fonctions_avances' => 'Funci&oacute;ns avanzadas',
'onglet_informations_personnelles' => 'Informaci&oacute;ns persoais',
'onglet_interactivite' => 'Interactividade',
'onglet_messagerie' => 'Mensaxer&iacute;a',
'onglet_messages_internes' => 'Mensaxes internas',
'onglet_messages_publics' => 'Mensaxes p&uacute;blicas',
'onglet_messages_vide' => 'Mensaxes sen texto',
'onglet_origine_visites' => 'Orixe das visitas',
'onglet_repartition_debut' => 'desde o principio',
'onglet_repartition_lang' => 'Distribuci&oacute;n por linguas',
'onglet_repartition_rubrique' => 'Distribuci&oacute;n por secci&oacute;ns',
'onglet_save_restaur_base' => 'Gardar/restaurar a base',
'onglet_vider_cache' => 'Baleirar a memoria cach&eacute;',
'ortho_trop_de_fautes2' => 'Comece por corrixir as faltas m&aacute;is evidentes e reint&eacute;nteo logo.',

// P
'pass_choix_pass' => 'Elixa s&uacute;a nova chave:',
'pass_erreur' => 'Erro',
'pass_erreur_acces_refuse' => '<b>Erro:</b> xa non ten acceso a este web.',
'pass_erreur_code_inconnu' => '<b>Erro:</b> este c&oacute;digo non se corresponde con ningu&eacute;n con acceso a este web.',
'pass_erreur_non_enregistre' => '<b>Erro:</b> o enderezo <tt>@email_oubli@</tt> non foi rexistrado neste web.',
'pass_erreur_non_valide' => '<b>Erro:</b> o correo-e. <tt>@email_oubli@</tt> non &eacute; v&aacute;lido!',
'pass_erreur_probleme_technique' => '<b>Erro:</b> debido a un problema t&eacute;cnico, a mensaxe de correo non puido ser enviada.',
'pass_espace_prive_bla' => 'O espazo privado deste web est&aacute; aberto &aacute;s
  visitas, logo de se rexistrar. Unha vez que se rexistre,
  poder&aacute; consultar os artigos en proceso de redacci&oacute;n,
  propor novos artigos e participar en todos os foros.',
'pass_forum_bla' => 'Solicitou participar nun foro reservado para os visitantes rexistrados.',
'pass_indiquez_cidessous' => 'Indique aqu&iacute; embaixo o enderezo do correo co que se
  rexistrara no seu momento. Recibir&aacute; un correo indic&aacute;ndolle os pasos a seguir para
  recuperar o seu acceso.',
'pass_mail_passcookie' => '(esta &eacute; unha mensaxe autom&aacute;tica)
Para recuperar o seu acceso a
@nom_site_spip@ (@adresse_site@)

Dir&iacute;xase ao seguinte enderezo:


     @sendcookie@

Daquela, poder&aacute; elixir unha nova chave
e reconectar co web.

',
'pass_mot_oublie' => 'Chave esquecida',
'pass_nouveau_enregistre' => 'A s&uacute;a nova chave foi rexistrada.',
'pass_nouveau_pass' => 'Nova chave',
'pass_ok' => 'ben',
'pass_oubli_mot' => 'Chave esquecida',
'pass_quitter_fenetre' => 'Pechar esta xanela',
'pass_rappel_login' => 'Lembra: o teu identificador (login) &eacute; &laquo; @login@ &laquo;.',
'pass_recevoir_mail' => 'Recibir&aacute;s un correo indic&aacute;ndote os pasos a seguir para recuperar o teu acceso.',
'pass_retour_public' => 'Volver ao web p&uacute;blico',
'pass_rien_a_faire_ici' => 'Non hai nada que facer aqu&iacute;.',
'pass_vousinscrire' => 'Inscr&iacute;base neste web',
'precedent' => 'anterior',
'previsualisation' => 'Previsualizaci&oacute;n',
'previsualiser' => 'Previsualizar',

// R
'retour' => 'Volver',

// S
'spip_conforme_dtd' => 'SPIP considera este documento conforme co seu DOCTYPE :',
'squelette' => 'esqueleto',
'squelette_inclus_ligne' => 'esqueleto inclu&iacute;do, li&ntilde;a',
'squelette_ligne' => 'esquelto, li&ntilde;a',
'stats_visites_et_popularite' => '@visites@ visitas; popularidade: @popularite@',
'suivant' => 'seguinte',

// T
'taille_ko' => '@taille@ KB',
'taille_mo' => '@taille@ MB',
'taille_octets' => '@taille@ bytes',
'texte_actualite_site_1' => 'Cando xa estea familiarizado/a coa interface, poder&aacute; premer sobre &laquo;',
'texte_actualite_site_2' => 'interface completa',
'texte_actualite_site_3' => '&raquo; para obter m&aacute;is posibilidades.',
'texte_creation_automatique_vignette' => 'A creaci&oacute;n autom&aacute;tica de vi&ntilde;etas de previsualizaci&oacute;n est&aacute; activada. Se emprega este formulario para subir ao servidor imaxes no(s) formato(s) @gd_formats@, ir&aacute;n acompa&ntilde;adas dunha vi&ntilde;eta cun tama&ntilde;o m&aacute;ximo de @taille_preview@ p&iacute;xels.',
'texte_documents_associes' => 'Os seguintes documentos est&aacute;n vencellados ao artigo,
  mais non foron inseridos directamente. Dependendo do formato da p&aacute;xina no web p&uacute;blico,
  poder&aacute;n aparecer en forma de documentos anexos.',
'texte_erreur_mise_niveau_base' => 'Hai un erro na base de datos tras a actualizaci&oacute;n.
  A imaxe <b>@fichier@</b> non foi engadida ao (artigo @id_article@).
  Tome nota deste aviso, reintente a actualizaci&oacute;n, 
  e finalmente verifique que as imaxes aparecen sempre
  nos artigos.',
'texte_erreur_visiteur' => 'Vostede tentou de acceder ao espazo privado cun identificador que non llo permite',
'texte_inc_auth_1' => 'Identificouse co
  identificador <b>@auth_login@</b>, mais este non existe na base de datos.
  Probe',
'texte_inc_auth_2' => 'reconectar',
'texte_inc_auth_3' => ', despois de reiniciar o seu navegador.',
'texte_inc_config' => 'As modificaci&oacute;ns que faga nestas p&aacute;xinas influir&aacute;n not&aacute;belmente no
  funcionamento do web. Recom&eacute;ndaselle non as modificar namentres que non estea 
  un pouco ao tanto do funcionamento do sistema SPIP.
  <br /><br /><b>En xeral, &eacute; moi recomend&aacute;bel que estas p&aacute;xinas sexan
  xestionadas polo/a webm&aacute;ster principal do web.</b>',
'texte_inc_meta_1' => 'O sistema encontrou un erro tras a escritura do ficheiro <code>@fichier@</code>. Rev&iacute;seo co perfil de administrador/a do web.',
'texte_inc_meta_2' => 'Comprobar os permisos de escritura',
'texte_inc_meta_3' => 'no cartafol <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'en proceso de redacci&oacute;n',
'texte_statut_poubelle' => 'no lixo',
'texte_statut_propose_evaluation' => 'proposto para avaliaci&oacute;n',
'texte_statut_publie' => 'publicado en li&ntilde;a',
'texte_statut_refuse' => 'rexeitado',
'titre_ajouter_mot_cle' => 'ENGADIR UNHA PALABRA-CLAVE:',
'titre_breve_proposee' => 'Breve proposta',
'titre_breve_publiee' => 'Breve publicada',
'titre_breve_refusee' => 'Breve rexeitada',
'titre_cadre_raccourcis' => 'ATALLOS:',
'titre_changer_couleur_interface' => 'Trocar a cor da interface',
'titre_forum' => 'Foro',
'titre_image_admin_article' => 'Podes administrar este artigo',
'titre_image_administrateur' => 'Xesti&oacute;n',
'titre_image_aide' => 'Axuda sobre este elemento',
'titre_image_auteur_supprime' => 'Autor/a suprimido',
'titre_image_redacteur' => 'Redactor/a sen acceso',
'titre_image_redacteur_02' => 'Redactor/a',
'titre_image_visiteur' => 'Visitante',
'titre_joindre_document' => 'ANEXAR UN DOCUMENTO',
'titre_liens_entrants' => 'As ligaz&oacute;ns entrantes do d&iacute;a',
'titre_mots_cles' => 'PALABRAS-CLAVE',
'titre_probleme_technique' => 'Atenci&oacute;n: un problema t&eacute;cnico (servidor SQL) impide o acceso a esta parte do web. Grazas pola s&uacute;a comprensi&oacute;n.',
'titre_publier_document' => 'PUBLICAR UN DOCUMENTO NESTE TEMA',
'titre_signatures_attente' => 'Sinaturas en espera de validaci&oacute;n',
'titre_signatures_confirmees' => 'Sinaturas confirmadas',
'titre_statistiques' => 'Estat&iacute;sticas do web',
'titre_titre_document' => 'T&iacute;tulo do documento:',
'todo' => 'pr&oacute;ximos',
'trad_reference' => '(artigo de referencia)',

// Z
'zbug_balise_b_aval' => '&nbsp;: baliza B en aval',
'zbug_balise_inexistante' => 'A baliza @balise@ est&aacute; mal declarada para @from@',
'zbug_balise_sans_argument' => 'Falta o argumento na baliza @balise@',
'zbug_boucle' => 'bucle',
'zbug_boucle_recursive_undef' => 'Bucle recursivo non definido: @nom@',
'zbug_calcul' => 'c&aacute;lculo',
'zbug_champ_hors_boucle' => 'Campo @champ@ f&oacute;ra de bucle',
'zbug_champ_hors_motif' => 'Campo @champ@ f&oacute;ra dun contexto @motif@',
'zbug_code' => 'c&oacute;digo',
'zbug_critere_inconnu' => 'Criterio desco&ntilde;ecido @critere@',
'zbug_distant_interdit' => 'Base externa prohibida',
'zbug_doublon_table_sans_cle_primaire' => 'Doublons sobre unha t&aacute;boa sen clave primaria at&oacute;mica',
'zbug_doublon_table_sans_index' => 'Doublons nunha t&aacute;boa sen index',
'zbug_erreur_boucle_double' => 'Dobre definici&oacute;n do boucle @id@',
'zbug_erreur_boucle_fermant' => 'Falta o cerre do bucle @id@',
'zbug_erreur_boucle_syntaxe' => 'Sintaxe de bucle incorrecta',
'zbug_erreur_compilation' => 'Erro de compilaci&amp;oacute;n',
'zbug_erreur_execution_page' => 'Erro de execuci&oacute;n',
'zbug_erreur_filtre' => 'Filtro @filtre@ non definido',
'zbug_erreur_meme_parent' => 'O criterio {meme_parent} non &eacute; aplic&aacute;bel m&aacute;is que aos bucles (FORUMS) ou (RUBRIQUES)',
'zbug_erreur_squelette' => 'Erro(s) no esqueleto',
'zbug_hors_compilation' => 'Deixar compilaci&oacute;n',
'zbug_info_erreur_squelette' => 'Erro no web',
'zbug_inversion_ordre_inexistant' => 'Inversi&oacute;n dunha orde inexistente',
'zbug_pagination_sans_critere' => 'A baliza #PAGINATION est&aacute; sen criterio {pagination} ou est&aacute; empregada nun bucle recursivo',
'zbug_parametres_inclus_incorrects' => 'Par&aacute;metro de inclusi&oacute;n incorrecto: @param@',
'zbug_profile' => 'Tempo de c&aacute;lculo&nbsp;: @time@',
'zbug_resultat' => 'resultado',
'zbug_serveur_indefini' => 'Servidor SQL non definido',
'zbug_statistiques' => 'Estat&iacute;sticas de consultas SQL ordenadas por duraci&oacute;n',
'zbug_table_inconnue' => 'T&aacute;boa SQL &laquo; @table@ &raquo; desco&ntilde;ecida',
'zxml_connus_attributs' => 'atributos co&amp;nacute;ecidos',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'atributo desco&amp;ntilde;ecido',
'zxml_inconnu_balise' => 'baliza desco&amp;ntilde;ecida',
'zxml_inconnu_entite' => 'entidade desco&ntilde;ecida',
'zxml_inconnu_id' => 'ID desco&amp;ntilde;ecida',
'zxml_mais_de' => 'mais de',
'zxml_non_conforme' => 'non &amp;eacute; conforme co motivo',
'zxml_non_fils' => 'non &amp;eacute; un f&amp;iacute;o de',
'zxml_nonvide_balise' => 'a baliza non est&amp;aacute; baleira',
'zxml_obligatoire_attribut' => 'atributo obrigatorio mais ausente en',
'zxml_succession_fils_incorrecte' => 'sucesi&amp;oacute;n de f&amp;iacute;os incorrecta',
'zxml_survoler' => 'sobrevoar para ver os correctos',
'zxml_valeur_attribut' => 'valor do atributo',
'zxml_vide_balise' => 'baliza baleira',
'zxml_vu' => 'vista previa'
);

?>
